@@ -12,6 +12,7 @@ const session = require('express-session')
 const SequelizeStore = require('connect-session-sequelize')(session.Store)
 const fs = require('fs')
 const path = require('path')
+const { Server } = require('socket.io')
 
 const morgan = require('morgan')
 const passportSocketIo = require('passport.socketio')
@@ -81,7 +82,16 @@ if (config.enableStatsApi) {
 }
 
 // socket io
-const io = require('socket.io')(server, { cookie: false })
+const io = new Server(server, {
+  pingInterval: config.heartbeatInterval,
+  pingTimeout: config.heartbeatTimeout,
+  cookie: false,
+  cors: {
+    origin: config.serverURL,
+    methods: ['GET', 'POST'],
+    credentials: true
+  }
+})
 
 // others
 const realtime = require('./lib/realtime.js')
@@ -272,9 +282,6 @@ io.use(passportSocketIo.authorize({
   success: realtime.onAuthorizeSuccess,
   fail: realtime.onAuthorizeFail
 }))
-// socket.io heartbeat
-io.set('heartbeat interval', config.heartbeatInterval)
-io.set('heartbeat timeout', config.heartbeatTimeout)
 // socket.io connection
 io.sockets.on('connection', realtime.connection)
 
@@ -349,8 +356,9 @@ function handleTermSignals () {
   alreadyHandlingTermSignals = true
   realtime.maintenance = true
   // disconnect all socket.io clients
-  Object.keys(io.sockets.sockets).forEach(function (key) {
-    const socket = io.sockets.sockets[key]
+  Array.from(io.sockets.sockets.keys()).forEach(function (key) {
+    const socket = io.sockets.sockets.get(key)
+    if (!socket) return
     // notify client server going into maintenance status
     socket.emit('maintenance')
     setTimeout(function () {
@@ -386,6 +394,13 @@ function handleTermSignals () {
           process.exit(0)
         }
       })
+    } else {
+      logger.warn(`Real time server not ready for shutdown, trying again (${currentCleanTry}/${maxCleanTries})...`)
+      currentCleanTry++
+      if (currentCleanTry > maxCleanTries) {
+        logger.error('Could not save note revisions after shutdown! Exiting.')
+        process.exit(1)
+      }
     }
   }, 200)
 }
