@@ -1,14 +1,16 @@
 'use strict'
 // external modules
 const crypto = require('crypto')
-const randomcolor = require('randomcolor')
+const Chance = require('chance')
 const config = require('./config')
 
 // core
 exports.generateAvatar = function (name) {
-  const color = randomcolor({
-    seed: name,
-    luminosity: 'dark'
+  // use darker colors for better contrast
+  const color = new Chance(name).color({
+    max_red: 150,
+    max_green: 150,
+    max_blue: 150
   })
   const letter = name.substring(0, 1).toUpperCase()
 
