@@ -1,13 +1,13 @@
 'use strict'
 // external modules
-const shortId = require('shortid')
+const nanoid = require('nanoid')
 
 module.exports = function (sequelize, DataTypes) {
   const Temp = sequelize.define('Temp', {
     id: {
       type: DataTypes.STRING,
       primaryKey: true,
-      defaultValue: shortId.generate
+      defaultValue: nanoid.nanoid
     },
     data: {
       type: DataTypes.TEXT
