@@ -4,7 +4,6 @@
 const cookie = require('cookie')
 const cookieParser = require('cookie-parser')
 const async = require('async')
-const randomcolor = require('randomcolor')
 const Chance = require('chance')
 const chance = new Chance()
 const moment = require('moment')
@@ -178,9 +177,9 @@ function finishUpdateNote (note, _note, callback) {
 // clean when user not in any rooms or user not in connected list
 setInterval(function () {
   async.each(Object.keys(users), function (key, callback) {
-    let socket = realtime.io.sockets.connected[key]
+    let socket = realtime.io.sockets.sockets.get(key)
     if ((!socket && users[key]) ||
-      (socket && (!socket.rooms || socket.rooms.length <= 0))) {
+      (socket && (!socket.rooms || socket.rooms.size <= 0))) {
       logger.debug(`cleaner found redundant user: ${key}`)
       if (!socket) {
         socket = {
@@ -711,7 +710,7 @@ function connection (socket) {
 
     // initialize user data
     // random color
-    let color = randomcolor()
+    let color = chance.color()
     // make sure color not duplicated or reach max random count
     if (notes[noteId]) {
       let randomcount = 0
@@ -724,7 +723,7 @@ function connection (socket) {
           }
         })
         if (found) {
-          color = randomcolor()
+          color = chance.color()
           randomcount++
         }
       } while (found && randomcount < maxrandomcount)
