@@ -1,6 +1,6 @@
 'use strict'
 
-const { rateLimit } = require('express-rate-limit')
+const { rateLimit, ipKeyGenerator } = require('express-rate-limit')
 const errors = require('../../errors')
 const config = require('../../config')
 
@@ -8,7 +8,7 @@ const determineKey = (req) => {
   if (req.user) {
     return req.user.id
   }
-  return req.header('cf-connecting-ip') || req.ip
+  return ipKeyGenerator(req.header('cf-connecting-ip') || req.ip)
 }
 
 // limits requests to user endpoints (login, signup) to 10 requests per 5 minutes
