@@ -24,7 +24,7 @@ import {
 
 import { saveAs } from 'file-saver'
 import List from 'list.js'
-import S from 'string'
+import { unescapeHtml } from './utils'
 
 require('./locale')
 
@@ -398,7 +398,7 @@ function buildTagsFilter (tags) {
   for (let i = 0; i < tags.length; i++) {
     tags[i] = {
       id: i,
-      text: S(tags[i]).unescapeHTML().s
+      text: unescapeHtml(tags[i])
     }
   }
   filtertags = tags
